@@ -1,23 +1,25 @@
 from collections import defaultdict
 from pathlib import Path
-from typing import Type, Dict, Any, Generator
+from typing import Type, Dict, Any, Generator, Union
 
 from collections_extended import setlist
+from fastapi import Query
 from lxml import etree
 from progress.bar import Bar
 from pydantic import BaseModel, Field
+from pydantic.dataclasses import dataclass
 from pyimporters_plugins.base import KnowledgeParserBase, KnowledgeParserOptions, Term, maybe_archive
 
 
 # from xml import etree
-
-
+@dataclass
 class MeSHOptions(KnowledgeParserOptions):
     """
-    Options for the RDF knowledge import
+    Options for the MeSH knowledge import
     """
-    branches : str = Field(None, description="Comma-separated list of branches to import, for example 'B,C' to import only descriptors belonging to the Organisms & Diseases categories")
+    branches : str = Query(None, description="Comma-separated list of branches to import, for example 'B,C' to import only descriptors belonging to the Organisms & Diseases categories")
 
+MeSHOptionsModel = MeSHOptions.__pydantic_model__
 
 # The top-level categories in the MeSH descriptor hierarchy are:
 MESH_CATEGORIES = {
@@ -41,8 +43,8 @@ MESH_CATEGORIES = {
 
 
 class MeSHKnowledgeParser(KnowledgeParserBase):
-    def parse(self, source: Path, options: Dict[str, Any], bar: Bar) -> Generator[Term, None, None]:
-        options = MeSHOptions(**options)
+    def parse(self, source: Path, options: Union[BaseModel, Dict[str, Any]], bar: Bar) -> Generator[Term, None, None]:
+        options = MeSHOptionsModel(**options) if isinstance(options, dict) else options
         allowed_branches = [b.strip() for b in options.branches.split(",") if b.strip() in MESH_CATEGORIES] if options.branches else list(MESH_CATEGORIES.keys())
         with maybe_archive(source) as file:
             mesh = etree.parse(file)
