@@ -3,7 +3,7 @@ from pathlib import Path
 from progress.bar import Bar
 from pyimporters_plugins.base import Term
 
-from pyimporters_mesh.mesh import MeSHKnowledgeParser, MeSHOptions
+from pyimporters_mesh.mesh import MeSHKnowledgeParser, MeSHOptions, MeSHOptionsModel
 
 
 def test_mesh():
@@ -22,7 +22,7 @@ def test_mesh():
 def test_mesh_branch():
     source = Path('data/small.zip')
     parser = MeSHKnowledgeParser()
-    options = MeSHOptions(branches="J")
+    options = MeSHOptionsModel(branches="J")
     concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
     assert len(concepts) == 1
 
